package com.supervision.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Assert;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.supervision.model.ProcessMedical;
import com.supervision.service.MedicalRecordService;
import com.supervision.service.ProcessMedicalService;
import com.supervision.service.ProcessService;
import com.supervision.vo.ask.ProcessMedicalResVo;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;


@Service
@RequiredArgsConstructor
@Slf4j
public class MedicalRecordServiceImpl implements MedicalRecordService {

    private final ProcessMedicalService processMedicalService;
    @Override
    public boolean saveMedicalRecord(ProcessMedical processMedical) {

        saveAssert(processMedical);

        return processMedicalService.save(processMedical);
    }

    @Override
    public ProcessMedicalResVo findByProcessId(String processId) {

        Assert.notEmpty(processId,"流程id不允许为空");

        return processMedicalService.findByProcessId(processId);
    }

    @Override
    public boolean updateMedicalRecord(ProcessMedical processMedical) {

        Assert.notEmpty(processMedical.getId(),"id 不能为空");

        return processMedicalService.updateById(processMedical);
    }

    private void saveAssert(ProcessMedical processMedical){
        Assert.notEmpty(processMedical.getProcessId(),"流程id不为空");
        Assert.notEmpty(processMedical.getMedicalRecId(),"病例id不能为空");
        Assert.notEmpty(processMedical.getPatientId(),"病人id不能为空");

        Integer count = processMedicalService.lambdaQuery().eq(ProcessMedical::getProcessId, processMedical.getProcessId()).count();
        Assert.isFalse(count > 0,"当前实例已经存在电子病例信息");
    }
}
